==> TencentMapSDK_iOS_3D_v6.6.0.zip: html/interface_q_m_s_driving_route_search_option.js <==
var interface_q_m_s_driving_route_search_option =
[
    [ "setAvoidPolygon:", "interface_q_m_s_driving_route_search_option.html#a35924bcd102cbd54652995959521d753", null ],
    [ "setFromCoordinate:", "interface_q_m_s_driving_route_search_option.html#ace8c1b47e61f4203320c252b501070ef", null ],
    [ "setPolicyWithType:", "interface_q_m_s_driving_route_search_option.html#af03ca7d42362693c381ba1a136a05d72", null ],
    [ "setToCoordinate:", "interface_q_m_s_driving_route_search_option.html#af3c843f1eacf8206616a3b402f6de184", null ],
    [ "setTrackPoints:", "interface_q_m_s_driving_route_search_option.html#a61cba7e4e47478804a9f9bd218a930c2", null ],
    [ "setWayPointsWithCoordinates:count:", "interface_q_m_s_driving_route_search_option.html#a71df55615ca239b3c4e3d9004f4aaa86", null ],
    [ "accuracy", "interface_q_m_s_driving_route_search_option.html#aebac251aabaff9651daf87afa8cb0a05", null ],
    [ "avoid_polygons", "interface_q_m_s_driving_route_search_option.html#a04a64283920e55956a7c60f4960dd4c7", null ],
    [ "cartype", "interface_q_m_s_driving_route_search_option.html#a95f54e7f1f9ae92d6b4ad56512181dae", null ],
    [ "departure_time", "interface_q_m_s_driving_route_search_option.html#a2d01912438fd23facaa51cd23f579037", null ],
    [ "from", "interface_q_m_s_driving_route_search_option.html#af5f87839a948836aee3a3f982f444b0a", null ],
    [ "from_poi", "interface_q_m_s_driving_route_search_option.html#ace43dda332fe75787cca89e00726c1cc", null ],
    [ "from_track", "interface_q_m_s_driving_route_search_option.html#a676c80345f312f6167d5eba1a1fc3ae6", null ],
    [ "get_mp", "interface_q_m_s_driving_route_search_option.html#a52c0ede915f7fb606b47fa2f2d36e9ff", null ],
    [ "get_speed", "interface_q_m_s_driving_route_search_option.html#ad6996f72693b0ced7ec3cfb70262e0b4", null ],
    [ "heading", "interface_q_m_s_driving_route_search_option.html#a31623d1ebc22732612a390420a14b55c", null ],
    [ "no_step", "interface_q_m_s_driving_route_search_option.html#a7fb561e7c66ca4b81f3590ee1b9997a9", null ],
    [ "perference", "interface_q_m_s_driving_route_search_option.html#adc3c2746f97f1fa7b2eba7c8ed9c78dd", null ],
    [ "plate_number", "interface_q_m_s_driving_route_search_option.html#a4f2833a4c671228041e1e7adefb3323d", null ],
    [ "policyType", "interface_q_m_s_driving_route_search_option.html#a5d51f356300e01886fb6f838f1e83519", null ],
    [ "speed", "interface_q_m_s_driving_route_search_option.html#a34cc7845977feed3a4c12328768117f4", null ],
    [ "tag_mode", "interface_q_m_s_driving_route_search_option.html#a51158ccb775628b95648a1029edac796", null ],
    [ "to", "interface_q_m_s_driving_route_search_option.html#a62ba0d4a6cb1100fd327e2b086c86f1b", null ],
    [ "to_poi", "interface_q_m_s_driving_route_search_option.html#a7fea054df89567aece11e7988aa7ed43", null ],
    [ "waypoints", "interface_q_m_s_driving_route_search_option.html#ad8841e63bacfdcbd867210842475b20f", null ]
];

==> TencentMapSDK_iOS_3D_v6.7.0.zip: html/interface_q_m_s_driving_route_search_option.js <==
var interface_q_m_s_driving_route_search_option =
[
    [ "setAvoidPolygon:", "interface_q_m_s_driving_route_search_option.html#a35924bcd102cbd54652995959521d753", null ],
    [ "setFromCoordinate:", "interface_q_m_s_driving_route_search_option.html#ace8c1b47e61f4203320c252b501070ef", null ],
    [ "setPolicyWithType:", "interface_q_m_s_driving_route_search_option.html#af03ca7d42362693c381ba1a136a05d72", null ],
    [ "setToCoordinate:", "interface_q_m_s_driving_route_search_option.html#af3c843f1eacf8206616a3b402f6de184", null ],
    [ "setTrackPoints:", "interface_q_m_s_driving_route_search_option.html#a61cba7e4e47478804a9f9bd218a930c2", null ],
    [ "setWayPointsWithCoordinates:count:", "interface_q_m_s_driving_route_search_option.html#a71df55615ca239b3c4e3d9004f4aaa86", null ],
    [ "accuracy", "interface_q_m_s_driving_route_search_option.html#aebac251aabaff9651daf87afa8cb0a05", null ],
    [ "avoid_polygons", "interface_q_m_s_driving_route_search_option.html#a04a64283920e55956a7c60f4960dd4c7", null ],
    [ "cartype", "interface_q_m_s_driving_route_search_option.html#a95f54e7f1f9ae92d6b4ad56512181dae", null ],
    [ "departure_time", "interface_q_m_s_driving_route_search_option.html#a2d01912438fd23facaa51cd23f579037", null ],
    [ "from", "interface_q_m_s_driving_route_search_option.html#af5f87839a948836aee3a3f982f444b0a", null ],
    [ "from_poi", "interface_q_m_s_driving_route_search_option.html#ace43dda332fe75787cca89e00726c1cc", null ],
    [ "from_track", "interface_q_m_s_driving_route_search_option.html#a676c80345f312f6167d5eba1a1fc3ae6", null ],
    [ "get_mp", "interface_q_m_s_driving_route_search_option.html#a52c0ede915f7fb606b47fa2f2d36e9ff", null ],
    [ "get_speed", "interface_q_m_s_driving_route_search_option.html#ad6996f72693b0ced7ec3cfb70262e0b4", null ],
    [ "heading", "interface_q_m_s_driving_route_search_option.html#a31623d1ebc22732612a390420a14b55c", null ],
    [ "no_step", "interface_q_m_s_driving_route_search_option.html#a7fb561e7c66ca4b81f3590ee1b9997a9", null ],
    [ "perference", "interface_q_m_s_driving_route_search_option.html#adc3c2746f97f1fa7b2eba7c8ed9c78dd", null ],
    [ "plate_number", "interface_q_m_s_driving_route_search_option.html#a4f2833a4c671228041e1e7adefb3323d", null ],
    [ "policy", "interface_q_m_s_driving_route_search_option.html#ae0bd7bfe51690d490b25902dd2e5e89c", null ],
    [ "policyType", "interface_q_m_s_driving_route_search_option.html#a5d51f356300e01886fb6f838f1e83519", null ],
    [ "speed", "interface_q_m_s_driving_route_search_option.html#a34cc7845977feed3a4c12328768117f4", null ],
    [ "tag_mode", "interface_q_m_s_driving_route_search_option.html#a51158ccb775628b95648a1029edac796", null ],
    [ "to", "interface_q_m_s_driving_route_search_option.html#a62ba0d4a6cb1100fd327e2b086c86f1b", null ],
    [ "to_poi", "interface_q_m_s_driving_route_search_option.html#a7fea054df89567aece11e7988aa7ed43", null ],
    [ "waypoints", "interface_q_m_s_driving_route_search_option.html#ad8841e63bacfdcbd867210842475b20f", null ]
];
